@@ -24,18 +24,20 @@ __all__: typing.Final[typing.List[str]] = [
     "bot_only",
     "human_only",
     "has_roles",
+    "has_guild_permissions",
     "check",
 ]
 
 import typing
 import functools
 
+import hikari
+
 from lightbulb import context
 from lightbulb import commands
 from lightbulb import errors
 
 if typing.TYPE_CHECKING:
-    import hikari
     from hikari.utilities import snowflake
 
 T_inv = typing.TypeVar("T_inv", bound=commands.Command)
@@ -85,6 +87,26 @@ async def _has_roles(ctx: context.Context, *, role_check):
     return True
 
 
+async def _has_guild_permissions(ctx: context.Context, *, permissions: typing.Sequence[hikari.Permissions]):
+    if not ctx.bot._has_stateful_cache:
+        raise NotImplementedError("The bot is stateless. Cache operations are not available")
+    if not (ctx.bot.intents & hikari.Intents.GUILDS) == hikari.Intents.GUILDS:
+        raise hikari.MissingIntentError(hikari.Intents.GUILDS)
+
+    await _guild_only(ctx)
+
+    roles = ctx.bot.cache.get_roles_view_for_guild(ctx.guild_id).values()
+    missing_perms = []
+    for perm in permissions:
+        if not any(role.permissions & perm for role in roles if role.id in ctx.member.role_ids):
+            missing_perms.append(perm)
+    if missing_perms:
+        raise errors.MissingRequiredPermission(
+            "You are missing one or more permissions required in order to run this command", permissions=missing_perms
+        )
+    return True
+
+
 def guild_only() -> typing.Callable[[T_inv], T_inv]:
     """
     A decorator that prevents a command from being used in direct messages.
@@ -189,6 +211,36 @@ def has_roles(
     return decorate
 
 
+def has_guild_permissions(perm1: hikari.Permissions, *permissions: hikari.Permissions):
+    """
+    A decorator that prevents the command from being used by a member missing any of the required
+    guild permissions (permissions granted by a role).
+
+    Args:
+        perm1 (:obj:`hikari.Permissions`): Permission to check for.
+        *permissions (:obj:`hikari.Permissions`): Additional permissions to check for.
+
+    Note:
+        This check will also prevent commands from being used in DMs, as you cannot have permissions
+        in a DM channel.
+
+    Warning:
+        This check is unavailable if your application is stateless and/or missing the intent
+        :obj:`hikari.Intents.GUILDS` and will **always** raise an error on command invocation if
+        either of these conditions are not met.
+    """
+
+    def decorate(command: T_inv) -> T_inv:
+        perms = set(perm1.split())
+        for permission in permissions:
+            for perm in permission.split():
+                perms.add(perm)
+        command.add_check(functools.partial(_has_guild_permissions, permissions=list(perms)))
+        return command
+
+    return decorate
+
+
 def check(check_func: typing.Callable[[context.Context], typing.Coroutine[typing.Any, typing.Any, bool]]):
     """
     A decorator which adds a custom check function to a command. The check function must be a coroutine (async def)
